# Chronicle

> Auto-generated by `lore export`. Full project memory — load this file when you need deep context.

> Auto-generated by `lore export` on 2026-03-22. Do not edit manually — use `lore add` to update.

## Facts

- smoke test WORKS _(trust: low 50)_
- Make sure the site uses the same look and RPG, SIGIL / Storybook vibe. Do not use Mkdocs or any out of scope styles. _site, pages, html_ _(trust: low 50)_
- auto-export after lore add is enabled _ux, workflow_ _(trust: low 50)_
- testing auto-export is wired up _test_ _(trust: low 50)_
- Make sure build LIC stay in compliance _lic, legal_ _(trust: low 50)_
- Insure that memory fetches allways work and do not cause race conditions. _memory, race_ _(trust: low 50)_

## Summaries

- memory entry and usage should flow clean with proper guides _memory_ _(trust: low 50)_
